==> vant-2.1.7.jar: META-INF/resources/webjars/vant/2.1.7/types/index.d.ts <==
import Vue from 'vue';
import { VanComponent } from './component';
import { Toast } from './toast';
import { Dialog } from './dialog';
import { Notify } from './notify';
import { Locale } from './locale';
import { Lazyload } from './lazyload';
import { ImagePreview } from './image-preview';

export const version: string;
export function install (vue: typeof Vue): void
export class ActionSheet extends VanComponent {}
export class AddressEdit extends VanComponent {}
export class AddressList extends VanComponent {}
export class Area extends VanComponent {}
export class Button extends VanComponent {}
export class Card extends VanComponent {}
export class Cell extends VanComponent {}
export class CellGroup extends VanComponent {}
export class CountDown extends VanComponent {}
export class Divider extends VanComponent {}
export class SwipeCell extends VanComponent {}
export class Checkbox extends VanComponent {}
export class CheckboxGroup extends VanComponent {}
export class Circle extends VanComponent {}
export class Col extends VanComponent {}
export class Collapse extends VanComponent {}
export class CollapseItem extends VanComponent {}
export class ContactCard extends VanComponent {}
export class ContactEdit extends VanComponent {}
export class ContactList extends VanComponent {}
export class CouponCell extends VanComponent {}
export class CouponList extends VanComponent {}
export class DatetimePicker extends VanComponent {}
export class DropdownItem extends VanComponent {}
export class DropdownMenu extends VanComponent {}
export class Field extends VanComponent {}
export class Grid extends VanComponent {}
export class GridItem extends VanComponent {}
export class GoodsAction extends VanComponent {}
export class GoodsActionButton extends VanComponent {}
export class GoodsActionIcon extends VanComponent {}
export class Icon extends VanComponent {}
export class Image extends VanComponent {}
export class IndexAnchor extends VanComponent {}
export class IndexBar extends VanComponent {}
export class Info extends VanComponent {}
export class List extends VanComponent {}
export class Loading extends VanComponent {}
export class NavBar extends VanComponent {}
export class NoticeBar extends VanComponent {}
export class NumberKeyboard extends VanComponent {}
export class Pagination extends VanComponent {}
export class Panel extends VanComponent {}
export class PasswordInput extends VanComponent {}
export class Picker extends VanComponent {}
export class Popup extends VanComponent {}
export class Progress extends VanComponent {}
export class PullRefresh extends VanComponent {}
export class Radio extends VanComponent {}
export class RadioGroup extends VanComponent {}
export class Rate extends VanComponent {}
export class Row extends VanComponent {}
export class Search extends VanComponent {}
export class Sidebar extends VanComponent {}
export class SidebarItem extends VanComponent {}
export class Skeleton extends VanComponent {}
export class Sku extends VanComponent {}
export class Slider extends VanComponent {}
export class Step extends VanComponent {}
export class Stepper extends VanComponent {}
export class Steps extends VanComponent {}
export class Sticky extends VanComponent {}
export class SubmitBar extends VanComponent {}
export class Swipe extends VanComponent {}
export class SwipeItem extends VanComponent {}
export class Switch extends VanComponent {}
export class SwitchCell extends VanComponent {}
export class Tab extends VanComponent {}
export class Tabbar extends VanComponent {}
export class TabbarItem extends VanComponent {}
export class Tabs extends VanComponent {}
export class Tag extends VanComponent {}
export class TreeSelect extends VanComponent {}
export class Uploader extends VanComponent {}
export {
  Toast,
  Dialog,
  Notify,
  Locale,
  Lazyload,
  ImagePreview
};

==> vant-3.0.0-rc.5.jar: META-INF/resources/webjars/vant/3.0.0-rc.5/types/index.d.ts <==
/* eslint-disable max-classes-per-file */
import { App } from 'vue';
import { VanComponent } from './component';
import { AddressEdit } from './address-edit';
import { Area } from './area';
import { Calendar } from './calendar';
import { Checkbox } from './checkbox';
import { CheckboxGroup } from './checkbox-group';
import { CollapseItem } from './collapse-item';
import { CountDown } from './count-down';
import { DatetimePicker } from './datetime-picker';
import { Dialog } from './dialog';
import { DropdownItem } from './dropdown-item';
import { Field } from './field';
import { Form } from './form';
import { ImagePreview } from './image-preview';
import { Lazyload } from './lazyload';
import { List } from './list';
import { Locale } from './locale';
import { Notify } from './notify';
import { Picker } from './picker';
import { Progress } from './progress';
import { Search } from './search';
import { Sku } from './sku';
import { Swipe } from './swipe';
import { SwipeCell } from './swipe-cell';
import { Tabs } from './tabs';
import { Toast } from './toast';
import { Uploader } from './uploader';

export const version: string;

export const install: (app: App) => any;

export class ActionSheet extends VanComponent {}
export class AddressList extends VanComponent {}
export class Badge extends VanComponent {}
export class Button extends VanComponent {}
export class Card extends VanComponent {}
export class Cascader extends VanComponent {}
export class Cell extends VanComponent {}
export class CellGroup extends VanComponent {}
export class Circle extends VanComponent {}
export class Col extends VanComponent {}
export class Collapse extends VanComponent {}
export class ContactCard extends VanComponent {}
export class ContactEdit extends VanComponent {}
export class ContactList extends VanComponent {}
export class CouponCell extends VanComponent {}
export class CouponList extends VanComponent {}
export class Divider extends VanComponent {}
export class DropdownMenu extends VanComponent {}
export class Empty extends VanComponent {}
export class Grid extends VanComponent {}
export class GridItem extends VanComponent {}
export class ActionBar extends VanComponent {}
export class ActionBarIcon extends VanComponent {}
export class ActionBarButton extends VanComponent {}
export class Icon extends VanComponent {}
export class Image extends VanComponent {}
export class IndexAnchor extends VanComponent {}
export class IndexBar extends VanComponent {}
export class Info extends VanComponent {}
export class Loading extends VanComponent {}
export class NavBar extends VanComponent {}
export class NoticeBar extends VanComponent {}
export class NumberKeyboard extends VanComponent {}
export class Overlay extends VanComponent {}
export class Pagination extends VanComponent {}
export class Panel extends VanComponent {}
export class PasswordInput extends VanComponent {}
export class Popover extends VanComponent {}
export class Popup extends VanComponent {}
export class PullRefresh extends VanComponent {}
export class Radio extends VanComponent {}
export class RadioGroup extends VanComponent {}
export class Rate extends VanComponent {}
export class Row extends VanComponent {}
export class ShareSheet extends VanComponent {}
export class Sidebar extends VanComponent {}
export class SidebarItem extends VanComponent {}
export class Skeleton extends VanComponent {}
export class Slider extends VanComponent {}
export class Step extends VanComponent {}
export class Stepper extends VanComponent {}
export class Steps extends VanComponent {}
export class Sticky extends VanComponent {}
export class SubmitBar extends VanComponent {}
export class SwipeItem extends VanComponent {}
export class Switch extends VanComponent {}
export class SwitchCell extends VanComponent {}
export class Tab extends VanComponent {}
export class Tabbar extends VanComponent {}
export class TabbarItem extends VanComponent {}
export class Tag extends VanComponent {}
export class TreeSelect extends VanComponent {}

export {
  AddressEdit,
  Area,
  Calendar,
  Checkbox,
  CheckboxGroup,
  CollapseItem,
  CountDown,
  DatetimePicker,
  Dialog,
  DropdownItem,
  Form,
  Field,
  ImagePreview,
  Lazyload,
  List,
  Locale,
  Notify,
  Picker,
  Progress,
  Search,
  Sku,
  Swipe,
  SwipeCell,
  Tabs,
  Toast,
  Uploader,
};
